@@ -1,10 +1,11 @@
 import asyncio
-import time
+import traceback
 from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from datetime import datetime
 from typing import List, Optional, Type
 
+from metaphor.models.crawler_run_metadata import CrawlerRunMetadata, Status
 from metaphor.models.metadata_change_event import MetadataChangeEvent
 from serde import deserialize
 from serde.json import from_json
@@ -59,13 +60,32 @@ class BaseExtractor(ABC):
 
     def run(self, config: RunConfig) -> List[MetadataChangeEvent]:
         """Callable function to extract metadata and send/post messages"""
-        start_time = time.time()
-        logger.info(f"Starting extractor {self.__class__.__name__} at {datetime.now()}")
+        start_time = datetime.now()
+        logger.info(f"Starting extractor {self.__class__.__name__} at {start_time}")
 
-        events: List[MetadataChangeEvent] = asyncio.run(self.extract(config))
+        run_status = Status.SUCCESS
 
+        events: List[MetadataChangeEvent] = []
+        try:
+            events = asyncio.run(self.extract(config))
+        except Exception as ex:
+            run_status = Status.FAILURE
+            logger.error(ex)
+            traceback.format_exc()
+
+        end_time = datetime.now()
+        entity_count = len(events)
         logger.info(
-            f"Fetched {len(events)} entities, took {format(time.time() - start_time, '.1f')} s"
+            f"Extractor ended with {run_status} at {end_time}, fetched {entity_count} entities, took {format((end_time - start_time).total_seconds(), '.1f')}s"
+        )
+
+        crawler_name = f"{self.__class__.__module__}.{self.__class__.__qualname__}"
+        run_metadata = CrawlerRunMetadata(
+            crawler_name=crawler_name,
+            start_time=start_time,
+            end_time=end_time,
+            status=run_status,
+            entity_count=float(entity_count),
         )
 
         if config.output.api is not None:
@@ -76,9 +96,8 @@ class BaseExtractor(ABC):
             file_sink = FileSink(config.output.file)
             file_sink.sink(events)
 
-        logger.info(f"Extractor ended successfully at {datetime.now()}")
-
         if file_sink is not None:
+            file_sink.sink_metadata(run_metadata)
             file_sink.sink_logs()
 
         return events
