@@ -5,6 +5,8 @@ from serde import deserialize
 
 from metaphor.snowflake.config import SnowflakeRunConfig
 
+DEFAULT_BATCH_SIZE = 100000
+
 
 @deserialize
 @dataclass
@@ -15,3 +17,6 @@ class SnowflakeUsageRunConfig(SnowflakeRunConfig):
 
     # Query filter to exclude certain usernames from the processing
     excluded_usernames: Set[str] = field(default_factory=lambda: set())
+
+    # The number of access logs fetched in a batch, default to 100000
+    batch_size: int = DEFAULT_BATCH_SIZE
